@@ -8,7 +8,7 @@ except ImportError:
     from io import StringIO
 
 
-__version__ = '0.2.2'
+__version__ = '0.2.3'
 
 
 def format_code(source,
@@ -103,12 +103,12 @@ def format_docstring(indentation, docstring,
     summary, description = split_summary_and_description(contents)
 
     if description:
+        # Compensate for triple quotes by temporarily prepending 3 spaces.
+        # This temporary prepending is undone below.
         if pre_summary_newline:
             summary = indentation + summary
         else:
-            # Compensate for triple quotes by temporarily prepending 3 spaces.
-            # This temporary prepending is undone below.
-            summary = 3 * ' ' + summary
+            summary = indentation + 3 * ' ' + summary
 
         return '''\
 """{pre_summary}{summary}
@@ -116,23 +116,18 @@ def format_docstring(indentation, docstring,
 {description}{post_description}
 {indentation}"""\
 '''.format(pre_summary=('\n' + indentation if pre_summary_newline else ''),
-           summary=normalize_summary(summary,
-                                     summary_wrap_length,
-                                     indentation).lstrip(),
+           summary=wrap_summary(normalize_summary(summary),
+                                wrap_length=summary_wrap_length,
+                                indentation=indentation).lstrip(),
            description='\n'.join([indent_non_indented(l, indentation).rstrip()
                                   for l in description.splitlines()]),
            post_description=('\n' if post_description_blank else ''),
            indentation=indentation)
     else:
-        if pre_summary_newline:
-            prefix = '\n' + indentation
-            suffix = '\n' + indentation
-        else:
-            prefix = ''
-            suffix = ''
-        return ('"""' + prefix +
-                normalize_summary(contents, summary_wrap_length) +
-                suffix + '"""')
+        return wrap_summary(indentation +
+                            '"""' + normalize_summary(contents) + '"""',
+                            wrap_length=summary_wrap_length,
+                            indentation=indentation).strip()
 
 
 def indent_non_indented(line, indentation):
@@ -175,7 +170,7 @@ def strip_docstring(docstring):
     return docstring.split(triple, 1)[1].rsplit(triple, 1)[0].strip()
 
 
-def normalize_summary(summary, wrap_length=0, indentation=''):
+def normalize_summary(summary):
     """Return normalized docstring summary."""
     # Remove newlines
     summary = re.sub('\s*\n\s*', ' ', summary.rstrip())
@@ -184,15 +179,19 @@ def normalize_summary(summary, wrap_length=0, indentation=''):
     if summary and summary[-1].isalnum():
         summary += '.'
 
-    # This is disabled by default since it goes against PEP 257
+    return summary
+
+
+def wrap_summary(summary, indentation, wrap_length):
+    """Return line-wrapped summary text."""
     if wrap_length > 0:
         import textwrap
-        summary = '\n'.join(
+        return '\n'.join(
             textwrap.wrap(summary,
                           width=wrap_length,
                           subsequent_indent=indentation)).strip()
-
-    return summary
+    else:
+        return summary
 
 
 def open_with_encoding(filename, encoding, mode='r'):
@@ -212,9 +211,10 @@ def detect_encoding(filename):
             with open(filename, 'rb') as input_file:
                 encoding = tokenize.detect_encoding(input_file.readline)[0]
 
-            # Check for correctness of encoding
-            with open(filename, encoding=encoding) as input_file:
-                input_file.read()
+                # Check for correctness of encoding
+                import io
+                with io.TextIOWrapper(input_file, encoding) as wrapper:
+                    wrapper.read()
 
             return encoding
         except (SyntaxError, LookupError, UnicodeDecodeError):
